@@ -4,6 +4,7 @@ import re
 import os
 import glob
 import logging
+import warnings
 
 import numpy as np
 import pandas as pd
@@ -571,7 +572,7 @@ class EnsembleSet(object):
         self,
         time_index="raw",
         column_keys=None,
-        cache_eclsum=True,
+        cache_eclsum=None,
         start_date=None,
         end_date=None,
     ):
@@ -611,6 +612,15 @@ class EnsembleSet(object):
             A DataFame of summary vectors for the ensembleset.
             The column 'ENSEMBLE' will denote each ensemble's name
         """
+        if cache_eclsum is not None:
+            warnings.warn(
+                (
+                    "cache_eclsum option to load_smry() is deprecated and "
+                    "will be removed in fmu-ensemble v2.0.0"
+                ),
+                FutureWarning,
+            )
+
         # Future: Multithread this:
         for _, ensemble in self._ensembles.items():
             ensemble.load_smry(
@@ -630,7 +640,7 @@ class EnsembleSet(object):
         self,
         time_index=None,
         column_keys=None,
-        cache_eclsum=False,
+        cache_eclsum=None,
         start_date=None,
         end_date=None,
     ):
@@ -664,6 +674,16 @@ class EnsembleSet(object):
             ENSEMBLE will distinguish the different ensembles by their
             respective names.
         """
+
+        if cache_eclsum is not None:
+            warnings.warn(
+                (
+                    "cache_eclsum option to get_smry() is deprecated and "
+                    "will be removed in fmu-ensemble v2.0.0"
+                ),
+                FutureWarning,
+            )
+
         smrylist = []
         for _, ensemble in self._ensembles.items():
             smry = ensemble.get_smry(
@@ -676,7 +696,7 @@ class EnsembleSet(object):
         return pd.DataFrame()
 
     def get_smry_dates(
-        self, freq="monthly", cache_eclsum=True, start_date=None, end_date=None
+        self, freq="monthly", cache_eclsum=None, start_date=None, end_date=None
     ):
         """Return list of datetimes from an ensembleset
 
@@ -704,6 +724,15 @@ class EnsembleSet(object):
             list of datetime.date.
         """
 
+        if cache_eclsum is not None:
+            warnings.warn(
+                (
+                    "cache_eclsum option to get_smry_dates() is deprecated and "
+                    "will be removed in fmu-ensemble v2.0.0"
+                ),
+                FutureWarning,
+            )
+
         rawdates = set()
         for _, ensemble in self._ensembles.items():
             rawdates = rawdates.union(
@@ -744,6 +773,11 @@ class EnsembleSet(object):
             summary file or no matched well names.
 
         """
+        warnings.warn(
+            "ensembleset.get_wellnames() is deprecated and "
+            "will be removed in later versions.",
+            FutureWarning,
+        )
         result = set()
         for _, ensemble in self._ensembles.items():
             result = result.union(ensemble.get_wellnames(well_match))
